@@ -4,6 +4,14 @@ use strict;
 use warnings;
 use 5.010;
 
+use File::Basename;
+use Test::File::ShareDir
+    -share => {
+        -module => {
+            'CGI::Github::Webhook' => dirname($0).'/../../static-badges/',
+        },
+};
+
 use CGI qw(-debug);
 my $cgi = CGI->new();
 
@@ -15,6 +23,7 @@ my $ghwh = CGI::Github::Webhook->new(
     secret => $ARGV[1],
     log => $ARGV[2],
     cgi => $cgi,
+    badge_to => $ARGV[3]."/badge.svg",
     );
 my $rc = $ghwh->run();
 
